<?php
// MSSQL SERVER CONFIG WIZARD
//
// Copyright (c) 2010 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: $

include_once(dirname(__FILE__).'/../configwizardhelper.inc.php');

// run the initialization function
mssqlserver_configwizard_init();

function mssqlserver_configwizard_init(){

	$name="mssqlserver";
	
	$args=array(
		CONFIGWIZARD_NAME => $name,
        CONFIGWIZARD_VERSION => "1.2",
		CONFIGWIZARD_TYPE => CONFIGWIZARD_TYPE_MONITORING,
		CONFIGWIZARD_DESCRIPTION => "Monitor a MSSQL Server",
		CONFIGWIZARD_DISPLAYTITLE => "MSSQL Server",
		CONFIGWIZARD_FUNCTION => "mssqlserver_configwizard_func",
		CONFIGWIZARD_PREVIEWIMAGE => "mssqlserver.png",
		);
		
	register_configwizard($name,$args);
	}



function mssqlserver_configwizard_func($mode="",$inargs=null,&$outargs,&$result){

	$wizard_name="mssqlserver";
	
	// initialize return code and output
	$result=0;
	$output="";
	
	// initialize output args - pass back the same data we got
	$outargs[CONFIGWIZARD_PASSBACK_DATA]=$inargs;


	switch($mode){
		case CONFIGWIZARD_MODE_GETSTAGE1HTML:
		
			$address=grab_array_var($inargs,"address","");
			$port=grab_array_var($inargs,"port","1433");
            $instance=grab_array_var($inargs,"instance","");
			$username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","master");
			
			$output='

	<div class="sectionTitle">MSSQL Database</div>
	
	<p>
	Specify the details for connecting to the MSSQL database you want to monitor.
	</p>
			
	<table>

	<tr>
	<td valign="top">
	<label>Address:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="40" name="address" id="address" value="'.htmlentities($address).'" class="textfield" /><br class="nobr" />
	The IP address or FQDNS name of the MSSQL server.<br><br>
	</td>
	</tr>
    
	<tr>
	<td valign="top">
	<label>Instance:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="40" name="instance" id="instace" value="'.htmlentities($instance).'" class="textfield" /><br class="nobr" />
	The instance of the MSSQL server you wish to connect to.<br><br>
	</td>
	</tr>    
	
	<tr>
	<td valign="top">
	<label>Port:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="5" name="port" id="port" value="'.htmlentities($port).'" class="textfield" /><br class="nobr" />
	The port to use to connect to the MSSQL server. This defaults to port 1433, however if you are using
    a named instance you should delete this field, or if you are certain set the port number here.<br /><br />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>Username:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="username" id="username" value="'.htmlentities($username).'" class="textfield" /><br class="nobr" />
	The username used to connect to the MSSQL server.<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>Password:</label><br class="nobr" />
	</td>
	<td>
<input type="password" size="20" name="password" id="password" value="'.htmlentities($password).'" class="textfield" /><br class="nobr" />
	The password used to connect to the MSSQL server.<br><br>
	</td>
	</tr>

	</table>

			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE1DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address","");
			$port=grab_array_var($inargs,"port","");
            $instance=grab_array_var($inargs,"instance","");
			$username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","master");
			
			// check for errors
			$errors=0;
			$errmsg=array();
			if(have_value($address)==false)
				$errmsg[$errors++]="No address specified.";
			if(have_value($port)==false && have_value($instance)==false)
				$errmsg[$errors++]="No port number or instance specified.";				
			if(have_value($username)==false)
				$errmsg[$errors++]="No username specified.";
			if(have_value($password)==false)
				$errmsg[$errors++]="No password specified.";
			if(have_value($database)==false)
				$errmsg[$errors++]="No database specified.";
				
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;
			
		case CONFIGWIZARD_MODE_GETSTAGE2HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$port=grab_array_var($inargs,"port","");
			$username=grab_array_var($inargs,"username","");
            $instance=grab_array_var($inargs,"instance","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","master");

			$ha=@gethostbyaddr($address);
			if($ha=="")
				$ha=$address;
			$hostname=grab_array_var($inargs,"hostname",$ha);
			
		
			$services=grab_array_var($inargs,"services",array(
				"connection_time"=>"on",
				"bufferhitratio"=>"on",
				"pagelooks" => "on",
				"freepages"=>"on",
				"targetpages"=>"on",
				"databasepages"=>"on",
				"stolenpages"=>"on",
				"lazywrites"=>"on",
				"readahead"=>"on",
				"pagereads"=>"on",
				"checkpoints"=>"on",
				"pagewrites"=>"on",
				"lockrequests"=>"on",
				"locktimeouts"=>"on",
				"deadlocks"=>"on",
				"lockwaits"=>"on",
				"lockwait"=>"on",
				"averagewait"=>"on",
				"pagesplits"=>"on",
				));
			$serviceargs=grab_array_var($inargs,"serviceargs",array(
				"connection_time_warning"=>"1",
				"connection_time_critical"=>"5",
				"bufferhitratio_warning"=>"90",
				"bufferhitratio_critical"=>"95",			
				"pagelooks_warning"=>"10",
				"pagelooks_critical"=>"20",
				"freepages_warning"=>"10",
				"freepages_critical"=>"20",
				"targetpages_warning"=>"70000",
				"targetpages_critical"=>"90000",
				"databasepages_warning"=>"300",
				"databasepages_critical"=>"600",
				"stolenpages_warning"=>"500",
				"stolenpages_critical"=>"700",
				"lazywrites_warning"=>"20",
				"lazywrites_critical"=>"30",
				"readahead_warning"=>"40",
				"readahead_critical"=>"50",
				"pagereads_warning"=>"20",
				"pagereads_critical"=>"30",
				"checkpoints_warning"=>"20",
				"checkpoints_critical"=>"30",
				"pagewrites_warning"=>"20",
				"pagewrites_critical"=>"30",
				"lockrequests_warning"=>"20",
				"lockrequests_critical"=>"30",
				"locktimeouts_warning"=>"20",
				"locktimeouts_critical"=>"30",
				"deadlocks_warning"=>"20",
				"deadlocks_critical"=>"30",
				"lockwaits_warning"=>"20",
				"lockwaits_critical"=>"30",
				"lockwait_warning"=>"2000",
				"lockwait_critical"=>"3000",
				"averagewait_warning"=>"20",
				"averagewait_critical"=>"30",
				"pagesplits_warning"=>"20",
				"pagesplits_critical"=>"30",				
				));
			
			$services_serial=grab_array_var($inargs,"services_serial");
			if($services_serial!="")
				$services=unserialize(base64_decode($services_serial));
			$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial");
			if($serviceargs_serial!=""){
				//echo "ARGSSERIAL: $serviceargs_serial<BR>\n";
				$serviceargs=unserialize(base64_decode($serviceargs_serial));
				}
		
			$output='
			
		<input type="hidden" name="address" value="'.htmlentities($address).'" />
		<input type="hidden" name="port" value="'.htmlentities($port).'" />
        <input type="hidden" name="instance" value="'.htmlentities($instance).'" />
		<input type="hidden" name="username" value="'.htmlentities($username).'" />
		<input type="hidden" name="password" value="'.htmlentities($password).'" />
		<input type="hidden" name="database" value="master">

	<div class="sectionTitle">MSSQL Server</div>
	
			
	<table>
	
	<tr>
	<td valign="top">
	<label>Address:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="address" id="address" value="'.htmlentities($address).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>Host Name:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="hostname" id="hostname" value="'.htmlentities($hostname).'" class="textfield" /><br class="nobr" />
	The name you\'d like to have associated with this MSSQL Database.
	</td>
	</tr>
    
	<tr>
	<td valign="top">
	<label>Instance:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="instance" id="instance" value="'.htmlentities($instance).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>    
	
	<tr>
	<td valign="top">
	<label>Port:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="5" name="port" id="port" value="'.htmlentities($port).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>Username:</label><br class="nobr" />
	</td>
	<td>
<input type="text" size="20" name="username" id="username" value="'.htmlentities($username).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>

	<tr>
	<td valign="top">
	<label>Password:</label><br class="nobr" />
	</td>
	<td>
<input type="password" size="20" name="password" id="password" value="'.htmlentities($password).'" class="textfield" disabled/><br class="nobr" />
	</td>
	</tr>


	<div class="sectionTitle">MSSQL Server Metrics</div>
	
	<p>Specify the metrics you\'d like to monitor on the MSSQL Server.</p>
	
	
	<table>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[connection_time]" '.is_checked(grab_array_var($services,"connection_time"),"on").'>
	</td>
	<td>
	<b>Connection Time</b><br> 
	Monitor the time it takes to connect to the server.<br>
	<label>Warning Threshold:</label> <input type="text" size="1" name="serviceargs[connection_time_warning]" value="'.htmlentities($serviceargs["connection_time_warning"]).'">sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="1" name="serviceargs[connection_time_critical]" value="'.htmlentities($serviceargs["connection_time_critical"]).'">sec<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[bufferhitratio]" '.is_checked(grab_array_var($services,"bufferhitratio"),"on").'>
	</td>
	<td>
	<b>Buffer Hit Ratio</b><br> 
	Monitor the Buffer Hit Ratio.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[bufferhitratio_warning]" value="'.htmlentities($serviceargs["bufferhitratio_warning"]).'" />&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[bufferhitratio_critical]" value="'.htmlentities($serviceargs["bufferhitratio_critical"]).'" /><br /><br />
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[pagelooks]" '.is_checked(grab_array_var($services,"pagelooks"),"on").'>
	</td>
	<td>
	<b>Page Looks</b><br> 
	Monitor the number of page looks per second.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[pagelooks_warning]" value="'.htmlentities($serviceargs["pagelooks_warning"]).'" />&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[pagelooks_critical]" value="'.htmlentities($serviceargs["pagelooks_critical"]).'" /><br /><br />
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[freepages]" '.is_checked(grab_array_var($services,"freepages"),"on").'>
	</td>
	<td>
	<b>Free Pages / Sec</b><br> 
	Monitor the free pages per second.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[freepages_warning]" value="'.htmlentities($serviceargs["freepages_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[freepages_critical]" value="'.htmlentities($serviceargs["freepages_critical"]).'">/sec<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[targetpages]" '.is_checked(grab_array_var($services,"targetpages"),"on").'>
	</td>
	<td>
	<b>Target Pages</b><br> 
	The amount of target pages per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[targetpages_warning]" value="'.htmlentities($serviceargs["targetpages_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[targetpages_critical]" value="'.htmlentities($serviceargs["targetpages_critical"]).'">/sec<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[databasepages]" '.is_checked(grab_array_var($services,"databasepages"),"on").'>
	</td>
	<td>
	<b>Database Pages</b><br> 
	The amount of database pages per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[databasepages_warning]" value="'.htmlentities($serviceargs["databasepages_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[databasepages_critical]" value="'.htmlentities($serviceargs["databasepages_critical"]).'">/sec<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[stolenpages]" '.is_checked(grab_array_var($services,"stolenpages"),"on").'>
	</td>
	<td>
	<b>Stolen Pages</b><br> 
	The amount of stolen pages per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[stolenpages_warning]" value="'.htmlentities($serviceargs["stolenpages_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[stolenpages_critical]" value="'.htmlentities($serviceargs["stolenpages_critical"]).'">/sec<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[lazywrites]" '.is_checked(grab_array_var($services,"lazywrites"),"on").'>
	</td>
	<td>
	<b>Lazy Writes</b><br> 
	The amount of lazy writes per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[lazywrites_warning]" value="'.htmlentities($serviceargs["lazywrites_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[lazywrites_critical]" value="'.htmlentities($serviceargs["lazywrites_critical"]).'">/sec<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[readahead]" '.is_checked(grab_array_var($services,"readahead"),"on").'>
	</td>
	<td>
	<b>Lazy Writes</b><br> 
	The amount of readaheads per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[readahead_warning]" value="'.htmlentities($serviceargs["readahead_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[readahead_critical]" value="'.htmlentities($serviceargs["readahead_critical"]).'">/sec<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[pagereads]" '.is_checked(grab_array_var($services,"pagereads"),"on").'>
	</td>
	<td>
	<b>Page Reads</b><br> 
	The amount of page reads per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[pagereads_warning]" value="'.htmlentities($serviceargs["pagereads_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[pagereads_critical]" value="'.htmlentities($serviceargs["pagereads_critical"]).'">/sec<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[checkpoints]" '.is_checked(grab_array_var($services,"checkpoints"),"on").'>
	</td>
	<td>
	<b>Check Pages</b><br> 
	The amount of checkpoint pages per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[checkpoints_warning]" value="'.htmlentities($serviceargs["checkpoints_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[checkpoints_critical]" value="'.htmlentities($serviceargs["checkpoints_critical"]).'">/sec<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[pagewrites]" '.is_checked(grab_array_var($services,"pagewrites"),"on").'>
	</td>
	<td>
	<b>Page Writes</b><br> 
	The amount of page writes per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[pagewrites_warning]" value="'.htmlentities($serviceargs["pagewrites_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[pagewrites_critical]" value="'.htmlentities($serviceargs["pagewrites_critical"]).'">/sec<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[lockrequests]" '.is_checked(grab_array_var($services,"lockrequests"),"on").'>
	</td>
	<td>
	<b>Lock Requests</b><br> 
	The amount of lock requests per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[lockrequests_warning]" value="'.htmlentities($serviceargs["lockrequests_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[lockrequests_critical]" value="'.htmlentities($serviceargs["lockrequests_critical"]).'">/sec<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[locktimeouts]" '.is_checked(grab_array_var($services,"locktimeouts"),"on").'>
	</td>
	<td>
	<b>Lock Timeouts</b><br> 
	The amount of lock timeouts per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[locktimeouts_warning]" value="'.htmlentities($serviceargs["locktimeouts_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[locktimeouts_critical]" value="'.htmlentities($serviceargs["locktimeouts_critical"]).'">/sec<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[deadlocks]" '.is_checked(grab_array_var($services,"deadlocks"),"on").'>
	</td>
	<td>
	<b>Deadlocks</b><br> 
	The amount of deadlocks per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[deadlocks_warning]" value="'.htmlentities($serviceargs["deadlocks_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[deadlocks_critical]" value="'.htmlentities($serviceargs["deadlocks_critical"]).'">/sec<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[lockwaits]" '.is_checked(grab_array_var($services,"lockwaits"),"on").'>
	</td>
	<td>
	<b>Lock Waits</b><br> 
	The amount of lockwaits per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[lockwaits_warning]" value="'.htmlentities($serviceargs["lockwaits_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[lockwaits_critical]" value="'.htmlentities($serviceargs["lockwaits_critical"]).'">/sec<br><br>
	</td>
	</tr>

	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[pagesplits]" '.is_checked(grab_array_var($services,"pagesplits"),"on").'>
	</td>
	<td>
	<b>Page Splits</b><br> 
	The amount of page splits per sec.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[pagesplits_warning]" value="'.htmlentities($serviceargs["pagesplits_warning"]).'">/sec&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[pagesplits_critical]" value="'.htmlentities($serviceargs["pagesplits_critical"]).'">/sec<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[lockwait]" '.is_checked(grab_array_var($services,"lockwait"),"on").'>
	</td>
	<td>
	<b>Lock Wait Time</b><br> 
	Monitor the lock wait time.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[lockwait_warning]" value="'.htmlentities($serviceargs["lockwait_warning"]).'">ms&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[lockwait_critical]" value="'.htmlentities($serviceargs["lockwait_critical"]).'">ms<br><br>
	</td>
	</tr>
	
	<tr>
	<td valign="top">
	<input type="checkbox" class="checkbox" name="services[averagewait]" '.is_checked(grab_array_var($services,"averagewait"),"on").'>
	</td>
	<td>
	<b>Average Wait Time</b><br> 
	Monitor the average wait time for execution.<br>
	<label>Warning Threshold:</label> <input type="text" size="2" name="serviceargs[averagewait_warning]" value="'.htmlentities($serviceargs["averagewait_warning"]).'">ms&nbsp;&nbsp;<label>Critical Threshold:</label> <input type="text" size="2" name="serviceargs[averagewait_critical]" value="'.htmlentities($serviceargs["averagewait_critical"]).'">ms<br><br>
	</td>
	</tr>
		
	</table>
	';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE2DATA:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$hostname=grab_array_var($inargs,"hostname");
			$port=grab_array_var($inargs,"port","");
            $instance=grab_array_var($inargs,"instance","");
			$username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","master");
				
			$services=grab_array_var($inargs,"services",array());
			$serviceargs=grab_array_var($inargs,"serviceargs",array());
			
		
			// check for errors
			$errors=0;
			$errmsg=array();
			if(is_valid_host_name($hostname)==false)
				$errmsg[$errors++]="Invalid host name.";
				
			if($errors>0){
				$outargs[CONFIGWIZARD_ERROR_MESSAGES]=$errmsg;
				$result=1;
				}
				
			break;

			
		case CONFIGWIZARD_MODE_GETSTAGE3HTML:
		
			// get variables that were passed to us
			$address=grab_array_var($inargs,"address");
			$hostname=grab_array_var($inargs,"hostname");
			$port=grab_array_var($inargs,"port","");
			$instance=grab_array_var($inargs,"instance","");
            $username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","master");
			
			$services=grab_array_var($inargs,"services");
			$serviceargs=grab_array_var($inargs,"serviceargs");
		
			$output='
			
		<input type="hidden" name="address" value="'.htmlentities($address).'" />
		<input type="hidden" name="hostname" value="'.htmlentities($hostname).'" />
		<input type="hidden" name="port" value="'.htmlentities($port).'" />
        <input type="hidden" name="instance" value="'.htmlentities($instance).'" />
		<input type="hidden" name="username" value="'.htmlentities($username).'" />
		<input type="hidden" name="password" value="'.htmlentities($password).'" />
		<input type="hidden" name="database" value="'.htmlentities($database).'" />
		<input type="hidden" name="services_serial" value="'.base64_encode(serialize($services)).'" />
		<input type="hidden" name="serviceargs_serial" value="'.base64_encode(serialize($serviceargs)).'" />
		
		<!--SERVICES='.serialize($services).'<BR>
		SERVICEARGS='.serialize($serviceargs).'<BR>-->
		
			';
			break;
			
		case CONFIGWIZARD_MODE_VALIDATESTAGE3DATA:
				
			break;
			
		case CONFIGWIZARD_MODE_GETFINALSTAGEHTML:
			
			
			$output='
			';
			break;
			
		case CONFIGWIZARD_MODE_GETOBJECTS:
		
			$hostname=grab_array_var($inargs,"hostname","");
			$address=grab_array_var($inargs,"address","");
			$hostaddress=$address;
			$port=grab_array_var($inargs,"port","");
            $instance=grab_array_var($inargs,"instance","");
			$username=grab_array_var($inargs,"username","");
			$password=grab_array_var($inargs,"password","");
			$database=grab_array_var($inargs,"database","master");
		
			$services_serial=grab_array_var($inargs,"services_serial","");
			$serviceargs_serial=grab_array_var($inargs,"serviceargs_serial","");
			
			$services=unserialize(base64_decode($services_serial));
			$serviceargs=unserialize(base64_decode($serviceargs_serial));
			
			/*
			echo "SERVICES<BR>";
			print_r($services);
			echo "<BR>";
			echo "SERVICEARGS<BR>";
			print_r($serviceargs);
			echo "<BR>";
			*/
			
			// save data for later use in re-entrance
			$meta_arr=array();
			$meta_arr["hostname"]=$hostname;
			$meta_arr["address"]=$address;
			$meta_arr["port"]=$port;
            $meta_arr["instance"]=$instance;
			$meta_arr["username"]=$username;
			$meta_arr["password"]=$password;
			$meta_arr["database"]=$database;
			$meta_arr["services"]=$services;
			$meta_arr["serviceargs"]=$serviceargs;
			save_configwizard_object_meta($wizard_name,$hostname,"",$meta_arr);			
			
			$objs=array();
			
			if(!host_exists($hostname)){
				$objs[]=array(
					"type" => OBJECTTYPE_HOST,
					"use" => "xiwizard_mssqlserver_host",
					"host_name" => $hostname,
					"address" => $hostaddress,
					"icon_image" => "mssqlserver.png",
					"statusmap_image" => "mssql.png",
					"_xiwizard" => $wizard_name,
					);
				}
			
			// common plugin opts
			$commonopts="-U '$username' -P '$password' ";
            if($instance)
                $commonopts .= "-I '$instance' ";
            if($port)
                $commonopts .= "-p $port ";

			foreach($services as $svcvar => $svcval){
			
				$pluginopts="";
				$pluginopts.=$commonopts;
			
				switch($svcvar){
								
					case "connection_time":
					
						$pluginopts.="--time2connect --warning ".$serviceargs["connection_time_warning"]." --critical ".$serviceargs["connection_time_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Connection Time",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;
								
					case "bufferhitratio":
					
						$pluginopts.="--bufferhitratio --warning ".$serviceargs["bufferhitratio_warning"].": --critical ".$serviceargs["bufferhitratio_critical"].":";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Buffer Hit Ratio",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;
								
					case "pagelooks":
					
						$pluginopts.="--pagelooks --warning ".$serviceargs["pagelooks_warning"]." --critical ".$serviceargs["pagelooks_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Page Looks Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;			
						

					case "freepages":
					
						$pluginopts.="--freepages --warning ".$serviceargs["freepages_warning"]." --critical ".$serviceargs["freepages_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Free Pages Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;
						
					case "targetpages":
					
						$pluginopts.="--targetpages --warning ".$serviceargs["targetpages_warning"]." --critical ".$serviceargs["targetpages_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Target Pages Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;
						
					case "databasepages":
					
						$pluginopts.="--databasepages --warning ".$serviceargs["databasepages_warning"]." --critical ".$serviceargs["databasepages_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Database Pages Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;		
						
					case "stolenpages":
					
						$pluginopts.="--stolenpages --warning ".$serviceargs["stolenpages_warning"]." --critical ".$serviceargs["stolenpages_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Stolen Pages Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;		
						
					case "lazywrites":
					
						$pluginopts.="--lazywrites --warning ".$serviceargs["lazywrites_warning"]." --critical ".$serviceargs["lazywrites_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Lazy Writes Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;		
						
					case "readahead":
					
						$pluginopts.="--readahead --warning ".$serviceargs["readahead_warning"]." --critical ".$serviceargs["readahead_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Readaheads Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	
						
					case "pagereads":
					
						$pluginopts.="--pagereads --warning ".$serviceargs["pagereads_warning"]." --critical ".$serviceargs["pagereads_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Page Reads Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	

					case "pagewrites":
					
						$pluginopts.="--pagewrites --warning ".$serviceargs["pagewrites_warning"]." --critical ".$serviceargs["pagewrites_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Page Writes Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	

					case "checkpoints":
					
						$pluginopts.="--checkpoints --warning ".$serviceargs["checkpoints_warning"]." --critical ".$serviceargs["checkpoints_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Checkpoint Pages Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	

					case "lockrequests":
					
						$pluginopts.="--lockrequests --warning ".$serviceargs["lockrequests_warning"]." --critical ".$serviceargs["lockrequests_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Lock Requests Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	

					case "locktimeouts":
					
						$pluginopts.="--locktimeouts --warning ".$serviceargs["locktimeouts_warning"]." --critical ".$serviceargs["locktimeouts_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Lock Timeouts Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	

					case "deadlocks":
					
						$pluginopts.="--deadlocks --warning ".$serviceargs["deadlocks_warning"]." --critical ".$serviceargs["deadlocks_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Deadlocks Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	

					case "lockwaits":
					
						$pluginopts.="--lockwaits --warning ".$serviceargs["lockwaits_warning"]." --critical ".$serviceargs["lockwaits_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Lock Waits Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	

					case "pagesplits":
					
						$pluginopts.="--pagesplits --warning ".$serviceargs["pagesplits_warning"]." --critical ".$serviceargs["pagesplits_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Page Splits Per Sec",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;							
						
					case "lockwait":
					
						$pluginopts.="--lockwait --warning ".$serviceargs["lockwait_warning"]." --critical ".$serviceargs["lockwait_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Lock Wait Times",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;	

					case "averagewait":
					
						$pluginopts.="--averagewait --warning ".$serviceargs["averagewait_warning"]." --critical ".$serviceargs["averagewait_critical"]."";
					
						$objs[]=array(
							"type" => OBJECTTYPE_SERVICE,
							"host_name" => $hostname,
							"service_description" => "MSSQL Average Wait Time",
							"use" => "xiwizard_mssqlserver_service",
							"check_command" => "check_xi_mssql_server!".$pluginopts,
							"_xiwizard" => $wizard_name,
							);
						break;							

					default:
						break;
					}
				}
				
			//~ echo "OBJECTS:<BR>";
			//~ print_r($objs);
			//~ exit();
					
			// return the object definitions to the wizard
			$outargs[CONFIGWIZARD_NAGIOS_OBJECTS]=$objs;
		
			break;
			
		default:
			break;			
		}
		
	return $output;
	}
	

?>
